@@ -1,27 +1,25 @@
 package Time::Checkpoint;
 
-use warnings;
-use strict;
+use 5.12.0;
+
+use feature qw{ state };
 
 use Time::HiRes      qw{ time };
 use Params::Validate qw{ :all };
-use Carp          qw{ confess };
 
 use constant IDX_CALLBACK => 0;
 use constant IDX_CKPOINTS => 1;
 
 sub new {
-	unshift @_, 'class';
+	my $package = shift;
 
-	validate( @_, {
-		class      => { 
-			type     => SCALAR,
-		},
-		callback   => { 
+	state $val = {
+		callback   => {
 			type     => CODEREF,
 			optional => 1,
 		},
-	} );
+	};
+	validate( @_, $val );
 
 	my $self = [ ];
 
@@ -31,14 +29,15 @@ sub new {
 
 	$self->[IDX_CKPOINTS] = { };
 
-	return bless $self, { @_ }->{class};
+	return bless $self, $package;
 }
 
 sub checkpoint {
-	validate_pos( @_,
+	state $val = [
 		{ isa  => 'Time::Checkpoint', },
 		{ type => SCALAR,             },
-	);
+	];
+	validate_pos( @_, @$val );
 
 	my ($self, $cp) = (@_);
 
@@ -55,23 +54,20 @@ sub checkpoint {
 		my $ot = $self->[IDX_CKPOINTS]->{$cp};
 		my $nt = time;
 		if ($self->[IDX_CALLBACK]) {
-			$self->[IDX_CALLBACK]->( $cp, $ot, $nt );
+			$self->[IDX_CALLBACK]->( $cp, $self->[IDX_CKPOINTS]->{$cp}, $nt );
 		}
 		$self->[IDX_CKPOINTS]->{$cp} = $nt;
 		return $nt - $ot;
 	}
-	else { 
-		# We have no idea why we're here.
-		confess;
-	}
 }
 
 sub cp { checkpoint( @_ ) }
 
 sub list_checkpoints {
-	validate_pos( @_,
-		{ isa  => 'Time::Checkpoint', },
-	);
+	state $val = [
+		{ isa => 'Time::Checkpoint' },
+	];
+	validate_pos( @_, @$val );
 	my ($self) = (@_);
 	my $points = $self->[IDX_CKPOINTS];
 	return $points;
@@ -80,10 +76,11 @@ sub list_checkpoints {
 sub lscp { list_checkpoints( @_ ) }
 
 sub checkpoint_status {
-	validate_pos( @_,
+	state $val = [
 		{ isa  => 'Time::Checkpoint', },
 		{ type => SCALAR,             },
-	);
+	];
+	validate_pos( @_, @$val );
 
 	my ($self, $cp) = (@_);
 
@@ -93,10 +90,11 @@ sub checkpoint_status {
 sub cpstat { checkpoint_status( @_ ) }
 
 sub checkpoint_remove {
-	validate_pos( @_,
+	state $val = [
 		{ isa  => 'Time::Checkpoint', },
 		{ type => SCALAR,             },
-	);
+	];
+	validate_pos( @_, @$val );
 
 	my ($self, $cp) = (@_);
 
@@ -112,10 +110,11 @@ sub checkpoint_remove {
 sub cprm { checkpoint_remove( @_ ) }
 
 sub flush {
-	validate_pos( @_,
+	state $val = [
 		{ isa  => 'Time::Checkpoint', },
 		{ type => SCALAR,             },
-	);
+	];
+	validate_pos( @_, @$val );
 
 	my ($self)= (@_);
 
@@ -230,14 +229,12 @@ Removes all checkpoints.
 
 =head1 AUTHOR
 
-  Alex J. Avriette
-  (alex@cpan.org)
+  Jane A. Avriette <jane@cpan.org>
 
 =head1 BUGS
 
-Fewer these days, but beasties abound. Because that's what
-beasties do.
+Yep.
 
 =cut
 
-# aja // vim:tw=80:ts=2:noet
+# jaa // vim:tw=80:ts=2:noet
